@@ -307,28 +307,6 @@ inline uint64x2_t PMULL_HIGH(const uint64x2_t a, const uint64x2_t b)
 #endif
 }
 
-/// \brief Vector extraction
-/// \param a the first value
-/// \param b the second value
-/// \param c the byte count
-/// \return vector
-/// \details VEXT_U8() extracts the first <tt>c</tt> bytes of vector
-///  <tt>a</tt> and the remaining bytes in <tt>b</tt>. VEXT_U8 is provided
-///  as GCC inline assembly due to Clang and lack of support for the intrinsic.
-/// \since Crypto++ 8.0
-inline uint64x2_t VEXT_U8(uint64x2_t a, uint64x2_t b, unsigned int c)
-{
-#if defined(_MSC_VER)
-    return vreinterpretq_u64_u8(vextq_u8(
-        vreinterpretq_u8_u64(a), vreinterpretq_u8_u64(b), c));
-#else
-    uint64x2_t r;
-    __asm__ ("ext   %0.16b, %1.16b, %2.16b, %3   \n\t"
-            :"=w" (r) : "w" (a), "w" (b), "I" (c) );
-    return r;
-#endif
-}
-
 /// \brief Vector extraction
 /// \tparam C the byte count
 /// \param a the first value
@@ -351,9 +329,9 @@ inline uint64x2_t VEXT_U8(uint64x2_t a, uint64x2_t b)
             :"=w" (r) : "w" (a), "w" (b), "I" (C) );
     return r;
 #endif
-//@}
 }
 
+//@}
 #endif // CRYPTOPP_ARM_PMULL_AVAILABLE
 
 #if CRYPTOPP_ARM_SHA3_AVAILABLE  || defined(CRYPTOPP_DOXYGEN_PROCESSING)
@@ -385,19 +363,19 @@ inline uint64x2_t VEOR3(uint64x2_t a, uint64x2_t b, uint64x2_t c)
 /// \param a the first value
 /// \param b the second value
 /// \param c the third value
-/// \return two-way exclusive OR of the values, then rotated by imm6
+/// \return two-way exclusive OR of the values, then rotated by c
 /// \details VXARQ() performs vxarq_u64(). VXARQ is provided as GCC inline assembly due
 ///  to Clang and lack of support for the intrinsic.
 /// \details VXARQ requires ARMv8.2.
 /// \since Crypto++ 8.6
-inline uint64x2_t VXAR(uint64x2_t a, uint64x2_t b, const int imm6)
+inline uint64x2_t VXAR(uint64x2_t a, uint64x2_t b, const int c)
 {
 #if defined(_MSC_VER)
-    return vxarq_u64(a, b, imm6);
+    return vxarq_u64(a, b, c);
 #else
     uint64x2_t r;
     __asm__ ("xar   %0.2d, %1.2d, %2.2d, %3   \n\t"
-            :"=w" (r) : "w" (a), "w" (b), "I" (imm6));
+            :"=w" (r) : "w" (a), "w" (b), "I" (c));
     return r;
 #endif
 }
